# `pendsim`: a pendulum-on-a-cart Sandbox!

A simple inverse-pendulum simulator, with a module to render animations of the simulation and API for custom controllers. ![(Example Video)](https://user-images.githubusercontent.com/33564709/116198178-817dde80-a6ea-11eb-8cdf-e0c53c922416.mp4)

[Package Documentation](http://rland93.github.io/pendulum/)

It uses rk45 to simulate a dynamic model of the simple inverse pendulum on a cart: [Inverted Pendulum](https://en.wikipedia.org/wiki/Inverted_pendulum).
